@@ -1048,4 +1048,12 @@ from pg_catalog.pg_partition P
 where not P.paristemplate
   and C.relnamespace = :schema_id::oid
 #INC> and pg_catalog.age(PR.xmin) <= pg_catalog.age(pg_catalog.xidin(pg_catalog.int8out(:tx)))
-order by PR.oid::bigint
\ No newline at end of file
+order by PR.oid::bigint
+
+---- RetrieveTimeZones ----
+select name, is_dst from pg_catalog.pg_timezone_names
+union distinct
+select abbrev as name, is_dst from pg_catalog.pg_timezone_abbrevs
+
+---- RetrieveDateStyle ----
+show DateStyle
\ No newline at end of file
