@@ -476,8 +476,9 @@ select
   Q.name,
   Q.object_id,
   Q.create_date,
-  q.modify_date,
-  Q.current_value,
+  Q.modify_date,
+  Q.start_value,
+  #V14: Q.last_used_value #: current_value #. as current_value,
   Q.increment,
   Q.minimum_value,
   Q.maximum_value,
